/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q;
typedef struct tySequence__xv3aaFd3JCw8NbmALHiezQ tySequence__xv3aaFd3JCw8NbmALHiezQ;
typedef struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA tyTuple__sPaDkVPSC0MkcoXCxPH9ccA;
typedef struct tyObject_OrderedTable__ZZvSdVkA2s2sIyifu4cpkg tyObject_OrderedTable__ZZvSdVkA2s2sIyifu4cpkg;
typedef struct tySequence__MlAD6nAPq9bHKla9cWiIZP0g tySequence__MlAD6nAPq9bHKla9cWiIZP0g;
typedef struct tySequence__oLpBKXzW3hF9aCVMo5EymfQ tySequence__oLpBKXzW3hF9aCVMo5EymfQ;
typedef struct tyTuple__jq7X5k7hWG0tdTZTDkiyGQ tyTuple__jq7X5k7hWG0tdTZTDkiyGQ;
typedef struct tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g;
typedef struct tyObject_Lexer__JC9bQ4bKzkuzV9bdqS4ju8yw tyObject_Lexer__JC9bQ4bKzkuzV9bdqS4ju8yw;
typedef struct tyObject_TBaseLexer__jTxk7Uc2dfr9aTDL2dZhO9ag tyObject_TBaseLexer__jTxk7Uc2dfr9aTDL2dZhO9ag;
typedef struct tyObject_Token__sNMaWRTImjqfh1DU9cmdQkA tyObject_Token__sNMaWRTImjqfh1DU9cmdQkA;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__awOivLjlO76sGdHY7nQUjQ tyTuple__awOivLjlO76sGdHY7nQUjQ;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ {
  RootObj Sup;
NI colonstate_;
NIM_BOOL commandAlreadyProcessed1;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf2;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph3;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend, void* ClE_0);
void* ClE_0;
} tyProc__ytI8fGyK2xSaJw9aKP5OSwQ;
typedef N_CLOSURE_PTR(void, TM__LO85BC9bl7tvXIPU7J9cRbtA_30) (tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend);
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
typedef NU8 tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg;
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend, tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd, void* ClE_0);
void* ClE_0;
} tyProc__OsAPLpj68tyxQOAO0hpUJg;
typedef N_CLOSURE_PTR(void, TM__LO85BC9bl7tvXIPU7J9cRbtA_38) (tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend, tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd);
typedef N_CLOSURE_PTR(void, TM__LO85BC9bl7tvXIPU7J9cRbtA_39) (tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend, tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd);
typedef N_CLOSURE_PTR(void, TM__LO85BC9bl7tvXIPU7J9cRbtA_40) (tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend, tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd);
typedef N_CLOSURE_PTR(void, TM__LO85BC9bl7tvXIPU7J9cRbtA_41) (tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend, tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd);
typedef N_CLOSURE_PTR(void, TM__LO85BC9bl7tvXIPU7J9cRbtA_42) (tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend, tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd);
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef N_CLOSURE_PTR(void, TM__LO85BC9bl7tvXIPU7J9cRbtA_46) (tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend);
typedef NU8 tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg;
typedef NU8 tyEnum_StringTableMode__G9c4wVDFIzf0xHmQvxso9a9cQ;
struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg {
  RootObj Sup;
NI counter;
tySequence__xv3aaFd3JCw8NbmALHiezQ* data;
tyEnum_StringTableMode__G9c4wVDFIzf0xHmQvxso9a9cQ mode;
};
struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA {
NimStringDesc* Field0;
NimStringDesc* Field1;
NIM_BOOL Field2;
};
typedef NU8 tyEnum_JsonNodeKind__RUngo7nCHe6O8aBGIcrhtg;
struct tyObject_OrderedTable__ZZvSdVkA2s2sIyifu4cpkg {
tySequence__MlAD6nAPq9bHKla9cWiIZP0g* data;
NI counter;
NI first;
NI last;
};
struct tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q {
NIM_BOOL isUnquoted;
tyEnum_JsonNodeKind__RUngo7nCHe6O8aBGIcrhtg kind;
union{
struct {NimStringDesc* str;
} _kind_1;
struct {NI64 num;
} _kind_2;
struct {NF fnum;
} _kind_3;
struct {NIM_BOOL bval;
} _kind_4;
struct {tyObject_OrderedTable__ZZvSdVkA2s2sIyifu4cpkg fields;
} _kind_6;
struct {tySequence__oLpBKXzW3hF9aCVMo5EymfQ* elems;
} _kind_7;
};
};
struct tyTuple__jq7X5k7hWG0tdTZTDkiyGQ {
NimStringDesc* Field0;
tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* Field1;
};
typedef tyTuple__jq7X5k7hWG0tdTZTDkiyGQ tyArray__4UNJAnCX9cgpcB9c9aDb4OAnA[13];
typedef NU8 tySet_tyEnum_MsgFlag__BzRTaQ6LrPDZKEKt9bswkOQ;
struct tyObject_TBaseLexer__jTxk7Uc2dfr9aTDL2dZhO9ag {
  RootObj Sup;
NI bufpos;
NCSTRING buf;
NimStringDesc* bufStorage;
NI bufLen;
tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g* stream;
NI lineNumber;
NI sentinel;
NI lineStart;
NI offsetBase;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, void* ClE_0);
void* ClE_0;
} tyProc__pIuD7iLYdwrBMntVRm61ZA;
struct tyObject_Lexer__JC9bQ4bKzkuzV9bdqS4ju8yw {
  tyObject_TBaseLexer__jTxk7Uc2dfr9aTDL2dZhO9ag Sup;
NI32 fileIdx;
NI indentAhead;
NI currLineIndent;
NIM_BOOL strongSpaces;
NIM_BOOL allowTabs;
tyProc__pIuD7iLYdwrBMntVRm61ZA errorHandler;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
};
typedef NU8 tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ;
typedef NU8 tyEnum_NumericalBase__thnLAz9aJwaXPrSfSppUBog;
struct tyObject_Token__sNMaWRTImjqfh1DU9cmdQkA {
tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ tokType;
NI indent;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
NI64 iNumber;
NF fNumber;
tyEnum_NumericalBase__thnLAz9aJwaXPrSfSppUBog base;
NI8 strongSpaceA;
NI8 strongSpaceB;
NimStringDesc* literal;
NI line;
NI col;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g* s, void* buf, NI bufLen, void* ClE_0);
void* ClE_0;
} tyProc__9cZV5JMJLsdOPMv55VbpOVg;
typedef N_CLOSURE_PTR(NI, TM__LO85BC9bl7tvXIPU7J9cRbtA_87) (tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g* s, void* buf, NI bufLen, void* ClE_0);
typedef NU8 tyEnum_BinaryPrefixMode__nDtrM19b3byM8T9ab2m7BwvA;
typedef NU8 tyEnum_FloatFormatMode__pNvEoaqwoxKyoASD11vSgQ;
typedef NimStringDesc* tyArray__ucDUDWdKfioXQrN9bCbG29bg[12];
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
struct tyTuple__awOivLjlO76sGdHY7nQUjQ {
NI Field0;
NI Field1;
NimStringDesc* Field2;
tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* Field3;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__oLpBKXzW3hF9aCVMo5EymfQ {
  TGenericSeq Sup;
  tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__xv3aaFd3JCw8NbmALHiezQ {
  TGenericSeq Sup;
  tyTuple__sPaDkVPSC0MkcoXCxPH9ccA data[SEQ_DECL_SIZE];
};
struct tySequence__MlAD6nAPq9bHKla9cWiIZP0g {
  TGenericSeq Sup;
  tyTuple__awOivLjlO76sGdHY7nQUjQ data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__Df2d8g8ATJgl6P2dnvrxRQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(void, clearPasses__ibt1gcb9bEEhDNlu5T9aSO9cg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(NF, epochTime__9aodCrWXscOGeNVh2cpuZkw_2)(void);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, setId__acBstbO4M1mPmWIX7UR34gidgen)(NI id);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringDesc* s);
static N_INLINE(NIM_BOOL, isEmpty__ZNWb41IwBSHCUIjlqlGoxgpathutils)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getNimcacheDir__oltK69akg0xLqkR2ITKbomg_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___0U8YTiSB6NvFwgvyimFN2Q)(NimStringDesc* base, NimStringDesc* f);
N_LIB_PRIVATE N_CLOSURE(void, compileToBackend__UB13APXtcoxv9c8fALEfCcA)(tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend, tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, customizeForBackend__PpXR3JlaylsNa64krjikeA)(tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__znuJizGq3isbcihOOtUY0A)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols, NimStringDesc* symbol, NimStringDesc* value);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__UhPXgqyDuuU9cKcS8FM883w)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols, NimStringDesc* symbol);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, commandCompileToC__ikP0vuP6oxqlYdG7q9cY7sA_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
N_LIB_PRIVATE N_NIMCALL(void, setOutFile__CQGypz7djD4eDZIXokhWpg_4)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, initVars__LewyFn4Dwlat7Ce2QWFbZA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, semanticPasses__1lULLV39aEGOHExTrkQptRQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(void, registerPass__VbG3eW9b2jtFMJI9bafKW9aRw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyTuple__euPCXX9bc3XzndEhYlqNS7g* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, verboseOpen__sGmRIy9cHg17AV3Qi5TDHlQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, verboseProcess__LKmuPCJqFCiS9axSu9axOmdw)(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* context, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, myOpen__aOG8hV039bfSL2VAm1lrf0Q)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myProcess__QAJdPOwMq9buTNGNGQO3ImA)(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* context, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myClose__q2jGmbBjsPumxfsrswciWg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* context, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, myOpen__uilCuJJCRRa62GOiz1PPkg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myProcess__mtin0JSWMFuuGt6GFCQvbg)(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myClose__f8dWe5MYj8ZjDSubo9c6jOg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__jkXTnxDf8MX1Pmks3s0XxA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noschangeFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, changeDetectedViaJsonBuildInstructions__O4FgngCxVDPcb9c52XSW7lA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* projectfile);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ccHasSaneOverflow__nRr0tdRhl8rTyvIdRrQiFA_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, compileProject__KlDcF6rnOBDQLo439cvjPjg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, NI32 projectFileIdx);
N_LIB_PRIVATE N_NIMCALL(void, cgenWriteModules__f9b9ctpv6DQPmjwWpbkP6UPw)(RootObj* backend, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config);
N_LIB_PRIVATE N_NIMCALL(void, callCCompiler__LewyFn4Dwlat7Ce2QWFbZA_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, writeJsonBuildInstructions__LewyFn4Dwlat7Ce2QWFbZA_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, writeDepsFile__1lULLV39aEGOHExTrkQptRQ_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___QVqo5OOQAdrjFqBsPctklw)(NimStringDesc* base, NimStringDesc* f);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(FILE*, open__cb1k9citqyT9a9brBSJAz8pkg)(NimStringDesc* filename, tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg mode, NI bufSize);
static N_INLINE(void, writeLine__45Em82MGXqv9biomV0DEbSgio)(FILE* f, NimStringDesc** x, NI xLen_0);
N_LIB_PRIVATE N_NIMCALL(void, write__PArlm09bKklm2BLsCg6YtaA)(FILE* f, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NI, len__BJm9cTslcy01z41qkbd1OIw)(tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ t);
static N_INLINE(NIM_BOOL, isFilled__5Qpmu5QqwDY0esVXn6wf7wtables)(NI hcode);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getModule__M1TGnt0pSqOaMTLwmaJc6A)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(void, close__fU6ZlJAtQ9bre04EDZLdGsA_3)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(void, commandCompileToJS__ikP0vuP6oxqlYdG7q9cY7sA_3)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
static N_INLINE(NIM_BOOL, isEmpty__bFmAIl9aL9a1UuSf9ckLiDlVwpathutils)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(void, setTarget__08masX9a9bS9a9b87wx8moDG9aQ)(tyObject_Target__9abOl5DLX8suLujOaHSvGzw* t, tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ o, tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, myOpen__gLZYKlu4ac5hh8GLNkHarg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myProcess__PZ51a8H3AQu4zYP9cwHpJag)(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myClose__yQE5q7IZnoaww0fGINiRdA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(void, wantMainModule__pfNwDAcuVGDsWqOQBMvUpw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, loadConfigs__YEwEmZgkg9cjY353WcQKcEQ)(NimStringDesc* cfg, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, commandDoc__kgKjuaW9cX0ivwgfDPX9bbdA)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, setNoteDefaults__Cv4hmdO043rkrIvOuDsovw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg note, NIM_BOOL enabled);
N_LIB_PRIVATE N_NIMCALL(void, commandDoc2__Oon9chQNpba2n9b4No4ZvTJA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, NIM_BOOL json);
N_LIB_PRIVATE N_NIMCALL(void, handleDocOutputOptions__XbQ9cZpzVfEPm68TZ4kxJow)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, assignIfDefault__rmcryqHo6AjmxL5CA65bog)(NI* result, NI val, NI def);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, myOpenJson__XkBOXGkEnDAtwimfvAgjZQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, processNodeJson__89cQsBb9a40vsSUZ26PjkTPQ)(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, closeJson__GrB9cG0YoTacDwWggL1RK7g)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, myOpen__XkBOXGkEnDAtwimfvAgjZQ_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, processNode__89cQsBb9a40vsSUZ26PjkTPQ_2)(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, close__GrB9cG0YoTacDwWggL1RK7g_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, finishDoc2Pass__9bL3sC70SreUG6ji8F9bCBvA)(NimStringDesc* project);
N_LIB_PRIVATE N_NIMCALL(void, commandBuildIndex__G9aVujEhUM3YWsYQBFeTRfQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* dir, NimStringDesc* outFile);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___hGkBbU4pIQDXq4yGHJbKBQ)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(void, commandRst2Html__kgKjuaW9cX0ivwgfDPX9bbdA_2)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, commandRst2TeX__kgKjuaW9cX0ivwgfDPX9bbdA_3)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, commandJson__kgKjuaW9cX0ivwgfDPX9bbdA_4)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, commandTags__kgKjuaW9cX0ivwgfDPX9bbdA_5)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___l9cjIIY6CNqmzrJ1PC9apeYg)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(void, commandGenDepend__ikP0vuP6oxqlYdG7q9cY7sA_4)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, myOpen__9aBBHcC5JwGAhBYrKj64M6g)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, addDotDependency__8wExOQ8P7cmaE9bvpwwGr9aA)(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, generateDot__PmWB9cH9aNqzmEfDVIh5xwsA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, NimStringDesc* project);
N_LIB_PRIVATE N_NIMCALL(void, execExternalProgram__WKaD677f7aLTxInYSr0wMw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* cmd, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getConfigVar__nT6pi8CimjduqrsM6Cc8mQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, newJArray__nXwnFPu9beTnGPwglrr7ztA_3)(void);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, percent___19ag6cl4fMjxytc9arHmLIbw_3)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, newJObject__nXwnFPu9beTnGPwglrr7ztA_2)(void);
static N_INLINE(void, X5BX5Deq___WmQhibcOp3ZlzI9bgifjalAjson)(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* obj, NimStringDesc* key, tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* val);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vlnBr1uIbtu0ntnZh6Askg)(tyObject_OrderedTable__ZZvSdVkA2s2sIyifu4cpkg* t, NimStringDesc* key, tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* val);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, percent___cUNUWspDCIapW3x6fFYyZQ_2)(NIM_BOOL b);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, percent___HoVDUa0lAOcINNYBrrSTiA)(tyTuple__jq7X5k7hWG0tdTZTDkiyGQ* keyVals, NI keyValsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetAppFilename)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPrefixDir__oltK69akg0xLqkR2ITKbomg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__PO49anyWCbe63GYNOs9cVuvg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* s, tySet_tyEnum_MsgFlag__BzRTaQ6LrPDZKEKt9bswkOQ flags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___79aIqF5QC8ZRJgu2hlv9bdjw)(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* node);
N_LIB_PRIVATE N_NIMCALL(void, commandCheck__ikP0vuP6oxqlYdG7q9cY7sA_5)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, parseFile__HSBHiITVPKlv327uAC12yw)(NI32 fileIdx, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config);
N_LIB_PRIVATE N_NIMCALL(void, commandScan__Ka9c1FxVXU1B1XFhzMdeNfg)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosaddFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mainCommandArg__sd9ayHTAsNJeqDPDlWgHRFA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g*, llStreamOpen__knWUQJsEzojha6AJCi6LcA)(NimStringDesc* filename, tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg mode);
N_LIB_PRIVATE N_NIMCALL(void, initToken__hOE5pLJGKF2PYhldDgGvPQ)(tyObject_Token__sNMaWRTImjqfh1DU9cmdQkA* L);
N_LIB_PRIVATE N_NIMCALL(void, openLexer__iF0HRQJbanfrtJmOXxkqaQ)(tyObject_Lexer__JC9bQ4bKzkuzV9bdqS4ju8yw* lex, NimStringDesc* filename, tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g* inputstream, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config);
N_LIB_PRIVATE N_NIMCALL(void, rawGetTok__9aV9cE1HeiD7SKKtdj1FAFoQ)(tyObject_Lexer__JC9bQ4bKzkuzV9bdqS4ju8yw* L, tyObject_Token__sNMaWRTImjqfh1DU9cmdQkA* tok);
N_LIB_PRIVATE N_NIMCALL(void, printTok__4skBakttVk9bVO8OszeMpMg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_Token__sNMaWRTImjqfh1DU9cmdQkA* tok);
N_LIB_PRIVATE N_NIMCALL(void, closeLexer__DwtnSrPK9cWJ9csJe89cdABpA)(tyObject_Lexer__JC9bQ4bKzkuzV9bdqS4ju8yw* lex);
N_LIB_PRIVATE N_NIMCALL(void, commandInteractive__ikP0vuP6oxqlYdG7q9cY7sA_6)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
N_LIB_PRIVATE N_NIMCALL(void, interactivePasses__ikP0vuP6oxqlYdG7q9cY7sA_7)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
N_LIB_PRIVATE N_NIMCALL(void, initDefines__hODM2As3BZvC4AAFuVvWwQ)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols);
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, myOpen__4vajIPhcf9a5bJvp6m9ciz6A)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myProcess__Owg2e1qJ9cqcKRBQZVvmIWg)(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myClose__9cMiASXBM9bgOmq0622U8U0g)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, compileSystemModule__bgKSaiGTRW4vbGh2XuGqSw_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, compileModule__G7A63DimkOmtueyLoB89c8w)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, NI32 fileIdx, tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__3HRSVgYDcnQTolSZGx1zjA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, makeStdinModule__9c3D8YlQlCYUtPb7tMWHTZg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processModule__zPTa50e0M05UK8aJ9bS48aw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g* stream);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g*, llStreamOpenStdIn__H3SJ6PGlvU4kIRYn9bKuDfA)(tyProc__9cZV5JMJLsdOPMv55VbpOVg r);
N_LIB_PRIVATE N_NIMCALL(NI, llReadFromStdin__ioi0zlIEx7dNasBjD9brSbA_2)(tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g* s, void* buf, NI bufLen);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuEndsWith)(NimStringDesc* s, NimStringDesc* suffix);
N_LIB_PRIVATE N_NIMCALL(void, commandJsonScript__ikP0vuP6oxqlYdG7q9cY7sA_8)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
N_LIB_PRIVATE N_NIMCALL(void, runJsonBuildInstructions__um1xBrr7i3dyUBg7kmYXvQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* projectfile);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, formatSize__sJSibvv0Wr8GrWWSB9cNm9aw)(NI64 bytes, NIM_CHAR decimalSep, tyEnum_BinaryPrefixMode__nDtrM19b3byM8T9ab2m7BwvA prefix, NIM_BOOL includeSpace);
N_LIB_PRIVATE N_NIMCALL(NI, getMaxMem__hrQB9bN29c1nR1E9cHqYcNcDA_2)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimIntToStr)(NI x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuformatFloat)(NF f, tyEnum_FloatFormatMode__pNvEoaqwoxKyoASD11vSgQ format, NI precision, NIM_CHAR decimalSep);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, absOutFile__ea9bsNo9cwchKzwCi7UjcP7g)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosextractFilename)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dump__Mb6F9aWuAmny8imBUjTGzOw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* pd);
N_LIB_PRIVATE N_NIMCALL(void, echoBinSafe)(NimStringDesc** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, msgKindToString__pY9bbQrdTPzM2HGfayOe6eQ)(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w kind);

/* section: NIM_merge_DATA */
extern TNimType NTI__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTI__p9aeeIinIungzas8OX4XRoQ_;
extern TNimType NTI__xHTZrq9aYs6boc9bCba0JbpQ_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
extern TNimType NTI__a8lycfSA25OQltN3OMeBsA_;
extern TNimType NTI__KfdHSsl8vyUCSI9b3inBcww_;
N_LIB_PRIVATE TNimType NTI__Df2d8g8ATJgl6P2dnvrxRQ_;
extern TNimType NTI__sM4lkSb7zS6F7OVMvW9cffQ_;
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_3, "r", 1);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_4, "doc0", 4);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_5, "doc2", 4);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_6, "doc", 3);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_7, "rst2html", 8);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_8, "rst2tex", 7);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_9, "jsondoc0", 8);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_10, "jsondoc2", 8);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_11, "jsondoc", 7);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_12, "ctags", 5);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_13, "buildindex", 10);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_14, "main.nim(239, 18) `ret.string.isAbsolute` ", 42);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_15, "htmldocs", 8);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_16, "c", 1);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_17, "cc", 2);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_18, "compile", 7);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_19, "compiletoc", 10);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_20, "cpp", 3);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_21, "compiletocpp", 12);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_22, "objc", 4);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_23, "compiletooc", 11);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_24, "js", 2);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_25, "compiletojs", 11);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_26, "run", 3);
extern TNimType NTI__4OBsgZ9cscH2JLUE5Wcz01g_;
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_27, "true", 4);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_28, "useNimRtl", 9);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_29, "main.nim(199, 33) `false` ", 26);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_31, "nimBetterRun", 12);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_32, "nimEmulateOverflowChecks", 24);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_33, ".deps", 5);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_34, "\012", 1);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_35, ".js", 3);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_36, "ecmascript", 10);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_37, "main.nim(214, 33) `false` ", 26);
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_43, "\'run\' command not available; rebuild with -d:tinyc", 50);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_45, "/home/runner/work/nightlies/nightlies/nim/compiler/main.nim", 59);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__LO85BC9bl7tvXIPU7J9cRbtA_44 = {((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_45),
((NI) 257),
((NI) 16)}
;
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_47, "gendepend", 9);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_48, "dump", 4);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_49, "check", 5);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_50, "parse", 5);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_51, "scan", 4);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_52, "secret", 6);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_53, "e", 1);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_54, "nop", 3);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_55, "help", 4);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_56, "jsonscript", 10);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_57, "nimdoc.cfg", 10);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_58, "nimdoc", 6);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_59, "nimdoc.tex.cfg", 14);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_60, "dot -Tpng -o", 12);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_61, "png", 3);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_62, "dot", 3);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_63, "dump.format", 11);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_64, "json", 4);
extern TNimType NTI__oLpBKXzW3hF9aCVMo5EymfQ_;
extern TNimType NTI__29cbg2fC1z5iM1PAI28kR5w_;
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_65, "version", 7);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_66, "1.4.2", 5);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_67, "nimExe", 6);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_68, "prefixdir", 9);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_69, "libpath", 7);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_70, "project_path", 12);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_71, "defined_symbols", 15);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_72, "lib_paths", 9);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_73, "lazyPaths", 9);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_74, "outdir", 6);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_75, "out", 3);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_76, "nimcache", 8);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_77, "hints", 5);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_78, "warnings", 8);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_79, "-- list of currently defined symbols --", 39);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_80, "-- end of list --", 17);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_81, "nimcheck", 8);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_82, "nim", 3);
extern TNimType NTI__JC9bQ4bKzkuzV9bdqS4ju8yw_;
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_83, "cannot open file: ", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__LO85BC9bl7tvXIPU7J9cRbtA_84 = {((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_45),
((NI) 162),
((NI) 14)}
;
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_85, "Beware: Indentation tokens depend on the parser\'s state!", 56);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_86, "nimscript", 9);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_88, "NimScript file does not exist: ", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__LO85BC9bl7tvXIPU7J9cRbtA_89 = {((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_45),
((NI) 357),
((NI) 16)}
;
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_90, ".nims", 5);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_91, "not a NimScript file: ", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__LO85BC9bl7tvXIPU7J9cRbtA_92 = {((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_45),
((NI) 359),
((NI) 16)}
;
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_93, "invalid command: ", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__LO85BC9bl7tvXIPU7J9cRbtA_94 = {((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_45),
((NI) 370),
((NI) 14)}
;
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_95, " peakmem", 8);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_96, "danger", 6);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_97, "Dangerous Release", 17);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_98, "release", 7);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_99, "Release", 7);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_100, "Debug", 5);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_101, "unknownOutput", 13);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_102, "loc", 3);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_103, "sec", 3);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_104, "mem", 3);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_105, "build", 5);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_106, "project", 7);
STRING_LITERAL(TM__LO85BC9bl7tvXIPU7J9cRbtA_107, "output", 6);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__LO85BC9bl7tvXIPU7J9cRbtA_108 = {((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_45),
((NI) 395),
((NI) 14)}
;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;
extern NI gFrontEndId__gyRrMPnY7JyC6tAu9bCfGng;

/* section: NIM_merge_PROCS */
static N_NIMCALL(void, Marker_tyRef__Df2d8g8ATJgl6P2dnvrxRQ)(void* p, NI op) {
	tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ* a;
	a = (tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ*)p;
	nimGCvisit((void*)(*a).conf2, op);
	nimGCvisit((void*)(*a).graph3, op);
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
static N_INLINE(void, setId__acBstbO4M1mPmWIX7UR34gidgen)(NI id) {
	gFrontEndId__gyRrMPnY7JyC6tAu9bCfGng = ((gFrontEndId__gyRrMPnY7JyC6tAu9bCfGng >= (NI)(id + ((NI) 1))) ? gFrontEndId__gyRrMPnY7JyC6tAu9bCfGng : (NI)(id + ((NI) 1)));
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__ZNWb41IwBSHCUIjlqlGoxgpathutils)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, customizeForBackend__PpXR3JlaylsNa64krjikeA)(tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend, void* ClE_0) {
	tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ* colonenvP_;
	colonenvP_ = (tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ*) ClE_0;
	{
		if (!((*(*colonenvP_).conf2).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 0))) goto LA3_;
		(*(*colonenvP_).conf2).backend = backend;
	}
	LA3_: ;
	defineSymbol__znuJizGq3isbcihOOtUY0A((*(*(*colonenvP_).graph3).config).symbols, reprEnum((NI)(*(*colonenvP_).conf2).backend, (&NTI__4OBsgZ9cscH2JLUE5Wcz01g_)), ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_27));
	switch ((*(*colonenvP_).conf2).backend) {
	case ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 1):
	{
		{
			if (!((*(*colonenvP_).conf2).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 0))) goto LA8_;
			(*(*colonenvP_).conf2).exc = ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 1);
		}
		LA8_: ;
	}
	break;
	case ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2):
	{
		{
			if (!((*(*colonenvP_).conf2).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 0))) goto LA13_;
			(*(*colonenvP_).conf2).exc = ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 2);
		}
		LA13_: ;
	}
	break;
	case ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 4):
	{
	}
	break;
	case ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 3):
	{
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = hcrOn__UhPXgqyDuuU9cKcS8FM883w((*colonenvP_).conf2);
			if (!T19_) goto LA20_;
			undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ((*(*colonenvP_).conf2).symbols, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_28));
		}
		LA20_: ;
	}
	break;
	case ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 0):
	{
		{
			if (!NIM_TRUE) goto LA25_;
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_29));
		}
		LA25_: ;
	}
	break;
	}
	{
		NIM_BOOL T29_;
		T29_ = (NIM_BOOL)0;
		T29_ = ((48 &((NU16)1<<((NU)((*(*colonenvP_).conf2).selectedGC)&15U)))!=0);
		if (!(T29_)) goto LA30_;
		T29_ = !(((*(*colonenvP_).conf2).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2)));
		LA30_: ;
		if (!T29_) goto LA31_;
		(*(*colonenvP_).conf2).exc = ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 3);
	}
	LA31_: ;
}
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(void, semanticPasses__1lULLV39aEGOHExTrkQptRQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyTuple__euPCXX9bc3XzndEhYlqNS7g T1_;
	tyTuple__euPCXX9bc3XzndEhYlqNS7g T2_;
	T1_.Field0 = verboseOpen__sGmRIy9cHg17AV3Qi5TDHlQ;
	T1_.Field1 = verboseProcess__LKmuPCJqFCiS9axSu9axOmdw;
	T1_.Field2 = NIM_NIL;
	T1_.Field3 = NIM_FALSE;
	registerPass__VbG3eW9b2jtFMJI9bafKW9aRw(g, (&T1_));
	T2_.Field0 = myOpen__aOG8hV039bfSL2VAm1lrf0Q;
	T2_.Field1 = myProcess__QAJdPOwMq9buTNGNGQO3ImA;
	T2_.Field2 = myClose__q2jGmbBjsPumxfsrswciWg;
	T2_.Field3 = NIM_TRUE;
	registerPass__VbG3eW9b2jtFMJI9bafKW9aRw(g, (&T2_));
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, writeLine__45Em82MGXqv9biomV0DEbSgio)(FILE* f, NimStringDesc** x, NI xLen_0) {
	{
		NimStringDesc** i;
		NI i_2;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < xLen_0)) goto LA3;
				i = (&x[i_2]);
				write__PArlm09bKklm2BLsCg6YtaA(f, (*i));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	write__PArlm09bKklm2BLsCg6YtaA(f, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_34));
}
static N_INLINE(NIM_BOOL, isFilled__5Qpmu5QqwDY0esVXn6wf7wtables)(NI hcode) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !((hcode == ((NI) 0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, writeDepsFile__1lULLV39aEGOHExTrkQptRQ_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	NimStringDesc* fname;
	NimStringDesc* T1_;
	FILE* f;
	T1_ = (NimStringDesc*)0;
	T1_ = rawNewString(((*(*g).config).projectName ? (*(*g).config).projectName->Sup.len : 0) + 5);
appendString(T1_, (*(*g).config).projectName);
appendString(T1_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_33));
	fname = slash___QVqo5OOQAdrjFqBsPctklw((*(*g).config).nimcacheDir, T1_);
	f = open__cb1k9citqyT9a9brBSJAz8pkg(fname, ((tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg) 1), ((NI) -1));
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** m;
		NI i;
		NI L;
		NI T3_;
		m = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w**)0;
		i = ((NI) 0);
		T3_ = ((*g).modules ? (*g).modules->Sup.len : 0);
		L = T3_;
		{
			while (1) {
				if (!(i < L)) goto LA5;
				m = &(*g).modules->data[i];
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T10_;
					if (!!(((*m) == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA8_;
					nimZeroMem((void*)T10_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T10_[0] = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg((*g).config, ((NI32) ((*(*m)).position)));
					writeLine__45Em82MGXqv9biomV0DEbSgio(f, T10_, 1);
				}
				LA8_: ;
				i += ((NI) 1);
			} LA5: ;
		}
	}
	{
		NI32 k;
		NI L_2;
		k = (NI32)0;
		L_2 = len__BJm9cTslcy01z41qkbd1OIw((*g).inclToMod);
		{
			NI h;
			NI colontmp_;
			NI T13_;
			NI res;
			h = (NI)0;
			colontmp_ = (NI)0;
			T13_ = (((*g).inclToMod.data ? (*g).inclToMod.data->Sup.len : 0)-1);
			colontmp_ = T13_;
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA15;
					h = res;
					{
						NIM_BOOL T18_;
						T18_ = (NIM_BOOL)0;
						T18_ = isFilled__5Qpmu5QqwDY0esVXn6wf7wtables((*g).inclToMod.data->data[h].Field0);
						if (!T18_) goto LA19_;
						k = (*g).inclToMod.data->data[h].Field1;
						{
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T23_;
							tyArray__nHXaesL0DJZHyVS07ARPRA T26_;
							T23_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
							T23_ = getModule__M1TGnt0pSqOaMTLwmaJc6A(g, k);
							if (!(T23_ == 0)) goto LA24_;
							nimZeroMem((void*)T26_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
							T26_[0] = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg((*g).config, k);
							writeLine__45Em82MGXqv9biomV0DEbSgio(f, T26_, 1);
						}
						LA24_: ;
					}
					LA19_: ;
					res += ((NI) 1);
				} LA15: ;
			}
		}
	}
	close__fU6ZlJAtQ9bre04EDZLdGsA_3(f);
}
N_LIB_PRIVATE N_NIMCALL(void, commandCompileToC__ikP0vuP6oxqlYdG7q9cY7sA_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph) {
	tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf;
	tyTuple__euPCXX9bc3XzndEhYlqNS7g T1_;
{	conf = (*graph).config;
	setOutFile__CQGypz7djD4eDZIXokhWpg_4(conf);
	initVars__LewyFn4Dwlat7Ce2QWFbZA(conf);
	semanticPasses__1lULLV39aEGOHExTrkQptRQ(graph);
	T1_.Field0 = myOpen__uilCuJJCRRa62GOiz1PPkg;
	T1_.Field1 = myProcess__mtin0JSWMFuuGt6GFCQvbg;
	T1_.Field2 = myClose__f8dWe5MYj8ZjDSubo9c6jOg;
	T1_.Field3 = NIM_FALSE;
	registerPass__VbG3eW9b2jtFMJI9bafKW9aRw(graph, (&T1_));
	{
		NIM_BOOL T4_;
		NimStringDesc* proj;
		T4_ = (NIM_BOOL)0;
		T4_ = ((4098 & (*conf).globalOptions) == 4096);
		if (T4_) goto LA5_;
		T4_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA(conf, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_31));
		LA5_: ;
		if (!T4_) goto LA6_;
		proj = noschangeFileExt((*conf).projectFull, ((NimStringDesc*) NIM_NIL));
		{
			NIM_BOOL T10_;
			T10_ = (NIM_BOOL)0;
			T10_ = changeDetectedViaJsonBuildInstructions__O4FgngCxVDPcb9c52XSW7lA(conf, proj);
			if (!!(T10_)) goto LA11_;
			nimCopyMem((void*)(*(*graph).config).notes, (NIM_CONST void*)(*(*graph).config).mainPackageNotes, 9);
			goto BeforeRet_;
		}
		LA11_: ;
	}
	LA6_: ;
	{
		NIM_BOOL T15_;
		T15_ = (NIM_BOOL)0;
		T15_ = ccHasSaneOverflow__nRr0tdRhl8rTyvIdRrQiFA_2(conf);
		if (!!(T15_)) goto LA16_;
		defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_32), ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_27));
	}
	LA16_: ;
	compileProject__KlDcF6rnOBDQLo439cvjPjg(graph, ((NI32) -1));
	{
		if (!(((NI) 0) < (*(*graph).config).errorCounter)) goto LA20_;
		goto BeforeRet_;
	}
	LA20_: ;
	cgenWriteModules__f9b9ctpv6DQPmjwWpbkP6UPw((*graph).backend, conf);
	{
		if (!!(((*conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 19)))) goto LA24_;
		callCCompiler__LewyFn4Dwlat7Ce2QWFbZA_2(conf);
		{
			NIM_BOOL T28_;
			T28_ = (NIM_BOOL)0;
			T28_ = hcrOn__UhPXgqyDuuU9cKcS8FM883w(conf);
			if (!!(T28_)) goto LA29_;
			writeJsonBuildInstructions__LewyFn4Dwlat7Ce2QWFbZA_3(conf);
		}
		LA29_: ;
		{
			if (!(((*(*graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 10))&63U)))!=0)) goto LA33_;
			writeDepsFile__1lULLV39aEGOHExTrkQptRQ_2(graph);
		}
		LA33_: ;
	}
	LA24_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isEmpty__bFmAIl9aL9a1UuSf9ckLiDlVwpathutils)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, commandCompileToJS__ikP0vuP6oxqlYdG7q9cY7sA_3)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph) {
	tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf;
	tyTuple__euPCXX9bc3XzndEhYlqNS7g T7_;
	conf = (*graph).config;
	(*conf).exc = ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 2);
	{
		NIM_BOOL T3_;
		NimStringDesc* T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmpty__bFmAIl9aL9a1UuSf9ckLiDlVwpathutils((*conf).outFile);
		if (!T3_) goto LA4_;
		T6_ = (NimStringDesc*)0;
		T6_ = rawNewString(((*conf).projectName ? (*conf).projectName->Sup.len : 0) + 3);
appendString(T6_, (*conf).projectName);
appendString(T6_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_35));
		asgnRef((void**) (&(*conf).outFile), T6_);
	}
	LA4_: ;
	setTarget__08masX9a9bS9a9b87wx8moDG9aQ((&(*(*graph).config).target), ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 26), ((tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag) 16));
	defineSymbol__znuJizGq3isbcihOOtUY0A((*(*graph).config).symbols, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_36), ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_27));
	semanticPasses__1lULLV39aEGOHExTrkQptRQ(graph);
	T7_.Field0 = myOpen__gLZYKlu4ac5hh8GLNkHarg;
	T7_.Field1 = myProcess__PZ51a8H3AQu4zYP9cwHpJag;
	T7_.Field2 = myClose__yQE5q7IZnoaww0fGINiRdA;
	T7_.Field3 = NIM_FALSE;
	registerPass__VbG3eW9b2jtFMJI9bafKW9aRw(graph, (&T7_));
	compileProject__KlDcF6rnOBDQLo439cvjPjg(graph, ((NI32) -1));
	{
		if (!(((*(*graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 10))&63U)))!=0)) goto LA10_;
		writeDepsFile__1lULLV39aEGOHExTrkQptRQ_2(graph);
	}
	LA10_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, compileToBackend__UB13APXtcoxv9c8fALEfCcA)(tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend, tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd, void* ClE_0) {
	tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ* colonenvP_;
	tyProc__ytI8fGyK2xSaJw9aKP5OSwQ T1_;
	colonenvP_ = (tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ*) ClE_0;
	(*colonenvP_).commandAlreadyProcessed1 = NIM_TRUE;
	(*(*colonenvP_).conf2).cmd = cmd;
	nimZeroMem((void*)(&T1_), sizeof(tyProc__ytI8fGyK2xSaJw9aKP5OSwQ));
	T1_.ClP_0 = customizeForBackend__PpXR3JlaylsNa64krjikeA; T1_.ClE_0 = colonenvP_;
	T1_.ClE_0? T1_.ClP_0(backend, T1_.ClE_0):((TM__LO85BC9bl7tvXIPU7J9cRbtA_30)(T1_.ClP_0))(backend);
	switch ((*(*colonenvP_).conf2).backend) {
	case ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 1):
	{
		commandCompileToC__ikP0vuP6oxqlYdG7q9cY7sA_2((*colonenvP_).graph3);
	}
	break;
	case ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2):
	{
		commandCompileToC__ikP0vuP6oxqlYdG7q9cY7sA_2((*colonenvP_).graph3);
	}
	break;
	case ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 4):
	{
		commandCompileToC__ikP0vuP6oxqlYdG7q9cY7sA_2((*colonenvP_).graph3);
	}
	break;
	case ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 3):
	{
		commandCompileToJS__ikP0vuP6oxqlYdG7q9cY7sA_3((*colonenvP_).graph3);
	}
	break;
	case ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 0):
	{
		{
			if (!NIM_TRUE) goto LA9_;
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_37));
		}
		LA9_: ;
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, commandDoc2__Oon9chQNpba2n9b4No4ZvTJA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, NIM_BOOL json) {
	NI T1_;
	handleDocOutputOptions__XbQ9cZpzVfEPm68TZ4kxJow((*graph).config);
	T1_ = (NI)0;
	assignIfDefault__rmcryqHo6AjmxL5CA65bog((&(*(*graph).config).errorMax), ((NI) IL64(9223372036854775807)), T1_);
	semanticPasses__1lULLV39aEGOHExTrkQptRQ(graph);
	{
		tyTuple__euPCXX9bc3XzndEhYlqNS7g T6_;
		if (!json) goto LA4_;
		T6_.Field0 = myOpenJson__XkBOXGkEnDAtwimfvAgjZQ;
		T6_.Field1 = processNodeJson__89cQsBb9a40vsSUZ26PjkTPQ;
		T6_.Field2 = closeJson__GrB9cG0YoTacDwWggL1RK7g;
		T6_.Field3 = NIM_FALSE;
		registerPass__VbG3eW9b2jtFMJI9bafKW9aRw(graph, (&T6_));
	}
	goto LA2_;
	LA4_: ;
	{
		tyTuple__euPCXX9bc3XzndEhYlqNS7g T8_;
		T8_.Field0 = myOpen__XkBOXGkEnDAtwimfvAgjZQ_2;
		T8_.Field1 = processNode__89cQsBb9a40vsSUZ26PjkTPQ_2;
		T8_.Field2 = close__GrB9cG0YoTacDwWggL1RK7g_2;
		T8_.Field3 = NIM_FALSE;
		registerPass__VbG3eW9b2jtFMJI9bafKW9aRw(graph, (&T8_));
	}
	LA2_: ;
	compileProject__KlDcF6rnOBDQLo439cvjPjg(graph, ((NI32) -1));
	finishDoc2Pass__9bL3sC70SreUG6ji8F9bCBvA((*(*graph).config).projectName);
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, commandGenDepend__ikP0vuP6oxqlYdG7q9cY7sA_4)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph) {
	tyTuple__euPCXX9bc3XzndEhYlqNS7g T1_;
	NimStringDesc* project;
	NimStringDesc* T2_;
	NimStringDesc* T3_;
	NimStringDesc* T4_;
	semanticPasses__1lULLV39aEGOHExTrkQptRQ(graph);
	T1_.Field0 = myOpen__9aBBHcC5JwGAhBYrKj64M6g;
	T1_.Field1 = addDotDependency__8wExOQ8P7cmaE9bvpwwGr9aA;
	T1_.Field2 = NIM_NIL;
	T1_.Field3 = NIM_FALSE;
	registerPass__VbG3eW9b2jtFMJI9bafKW9aRw(graph, (&T1_));
	compileProject__KlDcF6rnOBDQLo439cvjPjg(graph, ((NI32) -1));
	project = (*(*graph).config).projectFull;
	writeDepsFile__1lULLV39aEGOHExTrkQptRQ_2(graph);
	generateDot__PmWB9cH9aNqzmEfDVIh5xwsA(graph, project);
	T2_ = (NimStringDesc*)0;
	T3_ = (NimStringDesc*)0;
	T3_ = noschangeFileExt(project, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_61));
	T4_ = (NimStringDesc*)0;
	T4_ = noschangeFileExt(project, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_62));
	T2_ = rawNewString((T3_ ? T3_->Sup.len : 0) + (T4_ ? T4_->Sup.len : 0) + 13);
appendString(T2_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_60));
appendString(T2_, T3_);
appendChar(T2_, 32);
appendString(T2_, T4_);
	execExternalProgram__WKaD677f7aLTxInYSr0wMw((*graph).config, T2_, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 71));
}
static N_INLINE(void, X5BX5Deq___WmQhibcOp3ZlzI9bgifjalAjson)(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* obj, NimStringDesc* key, tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* val) {
	X5BX5Deq___vlnBr1uIbtu0ntnZh6Askg((&(*obj)._kind_6.fields), key, val);
}
N_LIB_PRIVATE N_NIMCALL(void, commandCheck__ikP0vuP6oxqlYdG7q9cY7sA_5)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph) {
	NI T1_;
	T1_ = (NI)0;
	assignIfDefault__rmcryqHo6AjmxL5CA65bog((&(*(*graph).config).errorMax), ((NI) IL64(9223372036854775807)), T1_);
	defineSymbol__znuJizGq3isbcihOOtUY0A((*(*graph).config).symbols, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_81), ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_27));
	semanticPasses__1lULLV39aEGOHExTrkQptRQ(graph);
	compileProject__KlDcF6rnOBDQLo439cvjPjg(graph, ((NI32) -1));
}
N_LIB_PRIVATE N_NIMCALL(void, commandScan__Ka9c1FxVXU1B1XFhzMdeNfg)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config) {
	NimStringDesc* f;
	NimStringDesc* T1_;
	tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g* stream;
	T1_ = (NimStringDesc*)0;
	T1_ = mainCommandArg__sd9ayHTAsNJeqDPDlWgHRFA(config);
	f = nosaddFileExt(T1_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_82));
	stream = llStreamOpen__knWUQJsEzojha6AJCi6LcA(f, ((tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg) 0));
	{
		tyObject_Lexer__JC9bQ4bKzkuzV9bdqS4ju8yw L;
		tyObject_Token__sNMaWRTImjqfh1DU9cmdQkA tok;
		if (!!((stream == ((tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g*) NIM_NIL)))) goto LA4_;
		nimZeroMem((void*)(&L), sizeof(tyObject_Lexer__JC9bQ4bKzkuzV9bdqS4ju8yw));
		L.Sup.Sup.m_type = (&NTI__JC9bQ4bKzkuzV9bdqS4ju8yw_);
		nimZeroMem((void*)(&tok), sizeof(tyObject_Token__sNMaWRTImjqfh1DU9cmdQkA));
		initToken__hOE5pLJGKF2PYhldDgGvPQ((&tok));
		openLexer__iF0HRQJbanfrtJmOXxkqaQ((&L), f, stream, cache, config);
		{
			while (1) {
				rawGetTok__9aV9cE1HeiD7SKKtdj1FAFoQ((&L), (&tok));
				printTok__4skBakttVk9bVO8OszeMpMg(config, (&tok));
				{
					if (!(tok.tokType == ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 1))) goto LA10_;
					goto LA6;
				}
				LA10_: ;
			}
		} LA6: ;
		closeLexer__DwtnSrPK9cWJ9csJe89cdABpA((&L));
	}
	goto LA2_;
	LA4_: ;
	{
		NimStringDesc* T13_;
		T13_ = (NimStringDesc*)0;
		T13_ = rawNewString((f ? f->Sup.len : 0) + 18);
appendString(T13_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_83));
appendString(T13_, f);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T13_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__LO85BC9bl7tvXIPU7J9cRbtA_84, NIM_FALSE);
	}
	LA2_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, interactivePasses__ikP0vuP6oxqlYdG7q9cY7sA_7)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph) {
	tyTuple__euPCXX9bc3XzndEhYlqNS7g T1_;
	tyTuple__euPCXX9bc3XzndEhYlqNS7g T2_;
	tyTuple__euPCXX9bc3XzndEhYlqNS7g T3_;
	initDefines__hODM2As3BZvC4AAFuVvWwQ((*(*graph).config).symbols);
	defineSymbol__znuJizGq3isbcihOOtUY0A((*(*graph).config).symbols, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_86), ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_27));
	T1_.Field0 = verboseOpen__sGmRIy9cHg17AV3Qi5TDHlQ;
	T1_.Field1 = verboseProcess__LKmuPCJqFCiS9axSu9axOmdw;
	T1_.Field2 = NIM_NIL;
	T1_.Field3 = NIM_FALSE;
	registerPass__VbG3eW9b2jtFMJI9bafKW9aRw(graph, (&T1_));
	T2_.Field0 = myOpen__aOG8hV039bfSL2VAm1lrf0Q;
	T2_.Field1 = myProcess__QAJdPOwMq9buTNGNGQO3ImA;
	T2_.Field2 = myClose__q2jGmbBjsPumxfsrswciWg;
	T2_.Field3 = NIM_TRUE;
	registerPass__VbG3eW9b2jtFMJI9bafKW9aRw(graph, (&T2_));
	T3_.Field0 = myOpen__4vajIPhcf9a5bJvp6m9ciz6A;
	T3_.Field1 = myProcess__Owg2e1qJ9cqcKRBQZVvmIWg;
	T3_.Field2 = myClose__9cMiASXBM9bgOmq0622U8U0g;
	T3_.Field3 = NIM_FALSE;
	registerPass__VbG3eW9b2jtFMJI9bafKW9aRw(graph, (&T3_));
}
N_LIB_PRIVATE N_NIMCALL(void, commandInteractive__ikP0vuP6oxqlYdG7q9cY7sA_6)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph) {
	NI T1_;
	T1_ = (NI)0;
	assignIfDefault__rmcryqHo6AjmxL5CA65bog((&(*(*graph).config).errorMax), ((NI) IL64(9223372036854775807)), T1_);
	interactivePasses__ikP0vuP6oxqlYdG7q9cY7sA_7(graph);
	compileSystemModule__bgKSaiGTRW4vbGh2XuGqSw_2(graph);
	{
		NI T4_;
		NI32 T7_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T8_;
		T4_ = ((*(*graph).config).commandArgs ? (*(*graph).config).commandArgs->Sup.len : 0);
		if (!(((NI) 0) < T4_)) goto LA5_;
		T7_ = (NI32)0;
		T7_ = fileInfoIdx__3HRSVgYDcnQTolSZGx1zjA((*graph).config, (*(*graph).config).projectFull);
		T8_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T8_ = compileModule__G7A63DimkOmtueyLoB89c8w(graph, T7_, 0);
		(void)(T8_);
	}
	goto LA2_;
	LA5_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m;
		tyProc__9cZV5JMJLsdOPMv55VbpOVg T10_;
		tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g* T11_;
		NIM_BOOL T12_;
		m = makeStdinModule__9c3D8YlQlCYUtPb7tMWHTZg(graph);
		(*m).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14)) & 63);
		nimZeroMem((void*)(&T10_), sizeof(tyProc__9cZV5JMJLsdOPMv55VbpOVg));
		T10_.ClP_0 = ((TM__LO85BC9bl7tvXIPU7J9cRbtA_87) (llReadFromStdin__ioi0zlIEx7dNasBjD9brSbA_2)); T10_.ClE_0 = NIM_NIL;
		T11_ = (tyObject_TLLStream__a5oZYQ9aTktYME2449ayEi6g*)0;
		T11_ = llStreamOpenStdIn__H3SJ6PGlvU4kIRYn9bKuDfA(T10_);
		T12_ = (NIM_BOOL)0;
		T12_ = processModule__zPTa50e0M05UK8aJ9bS48aw(graph, m, T11_);
	}
	LA2_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandJsonScript__ikP0vuP6oxqlYdG7q9cY7sA_8)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph) {
	NimStringDesc* proj;
	proj = noschangeFileExt((*(*graph).config).projectFull, ((NimStringDesc*) NIM_NIL));
	runJsonBuildInstructions__um1xBrr7i3dyUBg7kmYXvQ((*graph).config, proj);
}
N_LIB_PRIVATE N_NIMCALL(void, mainCommand__ikP0vuP6oxqlYdG7q9cY7sA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph) {
	tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ* colonenv_;
	tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
	NI T1_;
	NimStringDesc* T2_;
	NimStringDesc* T33_;
	NimStringDesc* T55_;
	colonenv_ = (tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ*)0;
	colonenv_ = (tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ*) newObj((&NTI__Df2d8g8ATJgl6P2dnvrxRQ_), sizeof(tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ));
	(*colonenv_).Sup.m_type = (&NTI__p9aeeIinIungzas8OX4XRoQ_);
	asgnRef((void**) (&(*colonenv_).graph3), graph);
	asgnRef((void**) (&(*colonenv_).conf2), (*(*colonenv_).graph3).config);
	cache = (*(*colonenv_).graph3).cache;
	clearPasses__ibt1gcb9bEEhDNlu5T9aSO9cg((*colonenv_).graph3);
	(*(*colonenv_).conf2).lastCmdTime = epochTime__9aodCrWXscOGeNVh2cpuZkw_2();
	asgnRef((void**) (&(*(*colonenv_).conf2).searchPaths), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*(*colonenv_).conf2).searchPaths), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
	T1_ = (*(*colonenv_).conf2).searchPaths->Sup.len++;
	T2_ = (NimStringDesc*)0;
	T2_ = (*(*colonenv_).conf2).searchPaths->data[T1_]; (*(*colonenv_).conf2).searchPaths->data[T1_] = copyStringRC1((*(*colonenv_).conf2).libpath);
	if (T2_) nimGCunrefNoCycle(T2_);
	setId__acBstbO4M1mPmWIX7UR34gidgen(((NI) 100));
	(*colonenv_).commandAlreadyProcessed1 = NIM_FALSE;
	{
		NIM_BOOL docLikeCmd2;
		NimStringDesc* T4_;
		docLikeCmd2 = NIM_FALSE;
		T4_ = (NimStringDesc*)0;
		T4_ = nsuNormalize((*(*colonenv_).conf2).command);
		switch (hashString(T4_) & 15) {
		case 0: 
if (eqStrings(T4_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_10))) goto LA6_;
break;
		case 1: 
if (eqStrings(T4_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_4))) goto LA6_;
if (eqStrings(T4_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_13))) goto LA6_;
break;
		case 2: 
if (eqStrings(T4_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_3))) goto LA5_;
break;
		case 3: 
if (eqStrings(T4_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_8))) goto LA6_;
break;
		case 4: 
if (eqStrings(T4_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_11))) goto LA6_;
break;
		case 12: 
if (eqStrings(T4_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_12))) goto LA6_;
break;
		case 13: 
if (eqStrings(T4_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_6))) goto LA6_;
break;
		case 15: 
if (eqStrings(T4_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_5))) goto LA6_;
if (eqStrings(T4_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_7))) goto LA6_;
if (eqStrings(T4_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_9))) goto LA6_;
break;
		}
		goto LA7_;
		LA5_: ;
		{
			(*(*colonenv_).conf2).globalOptions = ((*(*colonenv_).conf2).globalOptions | 12288);
		}
		goto LA8_;
		LA6_: ;
		{
			docLikeCmd2 = NIM_TRUE;
		}
		goto LA8_;
		LA7_: ;
		{
		}
		LA8_: ;
		{
			NIM_BOOL T14_;
			T14_ = (NIM_BOOL)0;
			T14_ = isEmpty__ZNWb41IwBSHCUIjlqlGoxgpathutils((*(*colonenv_).conf2).outDir);
			if (!T14_) goto LA15_;
			{
				NimStringDesc* ret;
				NimStringDesc* T32_;
				{
					if (!(((*(*colonenv_).conf2).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 13))&63U)))!=0)) goto LA20_;
					ret = getNimcacheDir__oltK69akg0xLqkR2ITKbomg_2((*colonenv_).conf2);
				}
				goto LA18_;
				LA20_: ;
				{
					ret = copyString((*(*colonenv_).conf2).projectPath);
				}
				LA18_: ;
				{
					NIM_BOOL T25_;
					T25_ = (NIM_BOOL)0;
					T25_ = nosisAbsolute(ret);
					if (!!(T25_)) goto LA26_;
					failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_14));
				}
				LA26_: ;
				{
					if (!docLikeCmd2) goto LA30_;
					ret = slash___0U8YTiSB6NvFwgvyimFN2Q(ret, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_15));
				}
				LA30_: ;
				T32_ = (NimStringDesc*)0;
				T32_ = (*(*colonenv_).conf2).outDir; (*(*colonenv_).conf2).outDir = copyStringRC1(ret);
				if (T32_) nimGCunrefNoCycle(T32_);
			}
		}
		LA15_: ;
	}
	T33_ = (NimStringDesc*)0;
	T33_ = nsuNormalize((*(*colonenv_).conf2).command);
	switch (hashString(T33_) & 15) {
	case 0: 
if (eqStrings(T33_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_21))) goto LA35_;
if (eqStrings(T33_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_23))) goto LA36_;
break;
	case 2: 
if (eqStrings(T33_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_18))) goto LA34_;
if (eqStrings(T33_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_25))) goto LA37_;
if (eqStrings(T33_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_3))) goto LA38_;
break;
	case 9: 
if (eqStrings(T33_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_16))) goto LA34_;
if (eqStrings(T33_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_26))) goto LA39_;
break;
	case 10: 
if (eqStrings(T33_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_17))) goto LA34_;
break;
	case 11: 
if (eqStrings(T33_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_20))) goto LA35_;
if (eqStrings(T33_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_24))) goto LA37_;
break;
	case 12: 
if (eqStrings(T33_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_19))) goto LA34_;
break;
	case 15: 
if (eqStrings(T33_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_22))) goto LA36_;
break;
	}
	goto LA40_;
	LA34_: ;
	{
		tyProc__OsAPLpj68tyxQOAO0hpUJg T43_;
		nimZeroMem((void*)(&T43_), sizeof(tyProc__OsAPLpj68tyxQOAO0hpUJg));
		T43_.ClP_0 = compileToBackend__UB13APXtcoxv9c8fALEfCcA; T43_.ClE_0 = colonenv_;
		T43_.ClE_0? T43_.ClP_0(((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 1), ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 21), T43_.ClE_0):((TM__LO85BC9bl7tvXIPU7J9cRbtA_38)(T43_.ClP_0))(((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 1), ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 21));
	}
	goto LA41_;
	LA35_: ;
	{
		tyProc__OsAPLpj68tyxQOAO0hpUJg T45_;
		nimZeroMem((void*)(&T45_), sizeof(tyProc__OsAPLpj68tyxQOAO0hpUJg));
		T45_.ClP_0 = compileToBackend__UB13APXtcoxv9c8fALEfCcA; T45_.ClE_0 = colonenv_;
		T45_.ClE_0? T45_.ClP_0(((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2), ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 21), T45_.ClE_0):((TM__LO85BC9bl7tvXIPU7J9cRbtA_39)(T45_.ClP_0))(((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2), ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 21));
	}
	goto LA41_;
	LA36_: ;
	{
		tyProc__OsAPLpj68tyxQOAO0hpUJg T47_;
		nimZeroMem((void*)(&T47_), sizeof(tyProc__OsAPLpj68tyxQOAO0hpUJg));
		T47_.ClP_0 = compileToBackend__UB13APXtcoxv9c8fALEfCcA; T47_.ClE_0 = colonenv_;
		T47_.ClE_0? T47_.ClP_0(((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 4), ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 21), T47_.ClE_0):((TM__LO85BC9bl7tvXIPU7J9cRbtA_40)(T47_.ClP_0))(((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 4), ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 21));
	}
	goto LA41_;
	LA37_: ;
	{
		tyProc__OsAPLpj68tyxQOAO0hpUJg T49_;
		nimZeroMem((void*)(&T49_), sizeof(tyProc__OsAPLpj68tyxQOAO0hpUJg));
		T49_.ClP_0 = compileToBackend__UB13APXtcoxv9c8fALEfCcA; T49_.ClE_0 = colonenv_;
		T49_.ClE_0? T49_.ClP_0(((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 3), ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 21), T49_.ClE_0):((TM__LO85BC9bl7tvXIPU7J9cRbtA_41)(T49_.ClP_0))(((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 3), ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 21));
	}
	goto LA41_;
	LA38_: ;
	{
		tyProc__OsAPLpj68tyxQOAO0hpUJg T51_;
		nimZeroMem((void*)(&T51_), sizeof(tyProc__OsAPLpj68tyxQOAO0hpUJg));
		T51_.ClP_0 = compileToBackend__UB13APXtcoxv9c8fALEfCcA; T51_.ClE_0 = colonenv_;
		T51_.ClE_0? T51_.ClP_0(((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 1), ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 21), T51_.ClE_0):((TM__LO85BC9bl7tvXIPU7J9cRbtA_42)(T51_.ClP_0))(((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 1), ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 21));
	}
	goto LA41_;
	LA39_: ;
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenv_).conf2, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_43), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__LO85BC9bl7tvXIPU7J9cRbtA_44, NIM_FALSE);
	}
	goto LA41_;
	LA40_: ;
	{
		tyProc__ytI8fGyK2xSaJw9aKP5OSwQ T54_;
		nimZeroMem((void*)(&T54_), sizeof(tyProc__ytI8fGyK2xSaJw9aKP5OSwQ));
		T54_.ClP_0 = customizeForBackend__PpXR3JlaylsNa64krjikeA; T54_.ClE_0 = colonenv_;
		T54_.ClE_0? T54_.ClP_0(((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 1), T54_.ClE_0):((TM__LO85BC9bl7tvXIPU7J9cRbtA_46)(T54_.ClP_0))(((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 1));
	}
	LA41_: ;
	T55_ = (NimStringDesc*)0;
	T55_ = nsuNormalize((*(*colonenv_).conf2).command);
	switch (hashString(T55_) & 31) {
	case 0: 
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_10))) goto LA61_;
break;
	case 1: 
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_4))) goto LA56_;
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_13))) goto LA63_;
break;
	case 2: 
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_48))) goto LA65_;
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_54))) goto LA71_;
break;
	case 4: 
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_50))) goto LA67_;
break;
	case 10: 
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_49))) goto LA66_;
break;
	case 12: 
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_55))) goto LA71_;
break;
	case 13: 
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_6))) goto LA57_;
break;
	case 16: 
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_53))) goto LA70_;
break;
	case 19: 
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_8))) goto LA59_;
break;
	case 20: 
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_11))) goto LA61_;
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_52))) goto LA69_;
break;
	case 26: 
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_51))) goto LA68_;
break;
	case 28: 
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_12))) goto LA62_;
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_56))) goto LA72_;
break;
	case 29: 
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_47))) goto LA64_;
break;
	case 31: 
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_5))) goto LA57_;
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_7))) goto LA58_;
if (eqStrings(T55_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_9))) goto LA60_;
break;
	}
	goto LA73_;
	LA56_: ;
	{
		wantMainModule__pfNwDAcuVGDsWqOQBMvUpw((*colonenv_).conf2);
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 8);
		loadConfigs__YEwEmZgkg9cjY353WcQKcEQ(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_57), cache, (*colonenv_).conf2);
		defineSymbol__znuJizGq3isbcihOOtUY0A((*(*colonenv_).conf2).symbols, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_58), ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_27));
		commandDoc__kgKjuaW9cX0ivwgfDPX9bbdA(cache, (*colonenv_).conf2);
	}
	goto LA74_;
	LA57_: ;
	{
		wantMainModule__pfNwDAcuVGDsWqOQBMvUpw((*colonenv_).conf2);
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 8);
		loadConfigs__YEwEmZgkg9cjY353WcQKcEQ(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_57), cache, (*colonenv_).conf2);
		defineSymbol__znuJizGq3isbcihOOtUY0A((*(*colonenv_).conf2).symbols, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_58), ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_27));
		setNoteDefaults__Cv4hmdO043rkrIvOuDsovw_2((*colonenv_).conf2, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 45), NIM_FALSE);
		setNoteDefaults__Cv4hmdO043rkrIvOuDsovw_2((*colonenv_).conf2, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 20), NIM_FALSE);
		commandDoc2__Oon9chQNpba2n9b4No4ZvTJA((*colonenv_).graph3, NIM_FALSE);
		{
			NIM_BOOL T79_;
			NimStringDesc* T83_;
			T79_ = (NIM_BOOL)0;
			T79_ = (((*(*colonenv_).conf2).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 27))&63U)))!=0);
			if (!(T79_)) goto LA80_;
			T79_ = (((*(*colonenv_).conf2).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 33))&63U)))!=0);
			LA80_: ;
			if (!T79_) goto LA81_;
			T83_ = (NimStringDesc*)0;
			T83_ = dollar___hGkBbU4pIQDXq4yGHJbKBQ((*(*colonenv_).conf2).outDir);
			commandBuildIndex__G9aVujEhUM3YWsYQBFeTRfQ((*colonenv_).conf2, T83_, ((NimStringDesc*) NIM_NIL));
		}
		LA81_: ;
	}
	goto LA74_;
	LA58_: ;
	{
		setNoteDefaults__Cv4hmdO043rkrIvOuDsovw_2((*colonenv_).conf2, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 20), NIM_FALSE);
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 16);
		loadConfigs__YEwEmZgkg9cjY353WcQKcEQ(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_57), cache, (*colonenv_).conf2);
		commandRst2Html__kgKjuaW9cX0ivwgfDPX9bbdA_2(cache, (*colonenv_).conf2);
	}
	goto LA74_;
	LA59_: ;
	{
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17);
		loadConfigs__YEwEmZgkg9cjY353WcQKcEQ(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_59), cache, (*colonenv_).conf2);
		commandRst2TeX__kgKjuaW9cX0ivwgfDPX9bbdA_3(cache, (*colonenv_).conf2);
	}
	goto LA74_;
	LA60_: ;
	{
		wantMainModule__pfNwDAcuVGDsWqOQBMvUpw((*colonenv_).conf2);
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 8);
		loadConfigs__YEwEmZgkg9cjY353WcQKcEQ(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_57), cache, (*colonenv_).conf2);
		defineSymbol__znuJizGq3isbcihOOtUY0A((*(*colonenv_).conf2).symbols, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_58), ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_27));
		commandJson__kgKjuaW9cX0ivwgfDPX9bbdA_4(cache, (*colonenv_).conf2);
	}
	goto LA74_;
	LA61_: ;
	{
		wantMainModule__pfNwDAcuVGDsWqOQBMvUpw((*colonenv_).conf2);
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 8);
		loadConfigs__YEwEmZgkg9cjY353WcQKcEQ(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_57), cache, (*colonenv_).conf2);
		defineSymbol__znuJizGq3isbcihOOtUY0A((*(*colonenv_).conf2).symbols, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_58), ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_27));
		commandDoc2__Oon9chQNpba2n9b4No4ZvTJA((*colonenv_).graph3, NIM_TRUE);
	}
	goto LA74_;
	LA62_: ;
	{
		wantMainModule__pfNwDAcuVGDsWqOQBMvUpw((*colonenv_).conf2);
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 8);
		loadConfigs__YEwEmZgkg9cjY353WcQKcEQ(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_57), cache, (*colonenv_).conf2);
		defineSymbol__znuJizGq3isbcihOOtUY0A((*(*colonenv_).conf2).symbols, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_58), ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_27));
		commandTags__kgKjuaW9cX0ivwgfDPX9bbdA_5(cache, (*colonenv_).conf2);
	}
	goto LA74_;
	LA63_: ;
	{
		NimStringDesc* T90_;
		wantMainModule__pfNwDAcuVGDsWqOQBMvUpw((*colonenv_).conf2);
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 8);
		loadConfigs__YEwEmZgkg9cjY353WcQKcEQ(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_57), cache, (*colonenv_).conf2);
		defineSymbol__znuJizGq3isbcihOOtUY0A((*(*colonenv_).conf2).symbols, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_58), ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_27));
		T90_ = (NimStringDesc*)0;
		T90_ = dollar___l9cjIIY6CNqmzrJ1PC9apeYg((*(*colonenv_).conf2).projectFull);
		commandBuildIndex__G9aVujEhUM3YWsYQBFeTRfQ((*colonenv_).conf2, T90_, (*(*colonenv_).conf2).outFile);
	}
	goto LA74_;
	LA64_: ;
	{
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 9);
		commandGenDepend__ikP0vuP6oxqlYdG7q9cY7sA_4((*colonenv_).graph3);
	}
	goto LA74_;
	LA65_: ;
	{
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 10);
		{
			NimStringDesc* T95_;
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* definedSymbols;
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* libpaths;
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* lazyPaths;
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* hints;
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* warnings;
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* dumpdata;
			tyArray__4UNJAnCX9cgpcB9c9aDb4OAnA T130_;
			NimStringDesc* T131_;
			NimStringDesc* T132_;
			NimStringDesc* T133_;
			NimStringDesc* T134_;
			T95_ = (NimStringDesc*)0;
			T95_ = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*colonenv_).conf2, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_63), ((NimStringDesc*) NIM_NIL));
			if (!eqStrings(T95_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_64))) goto LA96_;
			wantMainModule__pfNwDAcuVGDsWqOQBMvUpw((*colonenv_).conf2);
			definedSymbols = newJArray__nXwnFPu9beTnGPwglrr7ztA_3();
			{
				NimStringDesc* s;
				s = (NimStringDesc*)0;
				{
					NimStringDesc* key;
					NimStringDesc* val;
					key = (NimStringDesc*)0;
					val = (NimStringDesc*)0;
					{
						NI h;
						NI colontmp_;
						NI T101_;
						NI res;
						h = (NI)0;
						colontmp_ = (NI)0;
						T101_ = (((*(*(*colonenv_).conf2).symbols).data ? (*(*(*colonenv_).conf2).symbols).data->Sup.len : 0)-1);
						colontmp_ = T101_;
						res = ((NI) 0);
						{
							while (1) {
								if (!(res <= colontmp_)) goto LA103;
								h = res;
								{
									tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T108_;
									NI T109_;
									if (!(*(*(*colonenv_).conf2).symbols).data->data[h].Field2) goto LA106_;
									key = (*(*(*colonenv_).conf2).symbols).data->data[h].Field0;
									val = (*(*(*colonenv_).conf2).symbols).data->data[h].Field1;
									s = key;
									T108_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
									T108_ = percent___19ag6cl4fMjxytc9arHmLIbw_3(s);
									asgnRef((void**) (&(*definedSymbols)._kind_7.elems), (tySequence__oLpBKXzW3hF9aCVMo5EymfQ*) incrSeqV3((TGenericSeq*)((*definedSymbols)._kind_7.elems), (&NTI__oLpBKXzW3hF9aCVMo5EymfQ_)));
									T109_ = (*definedSymbols)._kind_7.elems->Sup.len++;
									asgnRef((void**) (&(*definedSymbols)._kind_7.elems->data[T109_]), T108_);
								}
								LA106_: ;
								res += ((NI) 1);
							} LA103: ;
						}
					}
				}
			}
			libpaths = newJArray__nXwnFPu9beTnGPwglrr7ztA_3();
			lazyPaths = newJArray__nXwnFPu9beTnGPwglrr7ztA_3();
			{
				NimStringDesc** dir;
				NI i;
				NI L;
				NI T111_;
				dir = (NimStringDesc**)0;
				i = ((NI) 0);
				T111_ = ((*(*colonenv_).conf2).searchPaths ? (*(*colonenv_).conf2).searchPaths->Sup.len : 0);
				L = T111_;
				{
					while (1) {
						tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T114_;
						NI T115_;
						if (!(i < L)) goto LA113;
						dir = (&(*(*colonenv_).conf2).searchPaths->data[i]);
						T114_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
						T114_ = percent___19ag6cl4fMjxytc9arHmLIbw_3((*dir));
						asgnRef((void**) (&(*libpaths)._kind_7.elems), (tySequence__oLpBKXzW3hF9aCVMo5EymfQ*) incrSeqV3((TGenericSeq*)((*libpaths)._kind_7.elems), (&NTI__oLpBKXzW3hF9aCVMo5EymfQ_)));
						T115_ = (*libpaths)._kind_7.elems->Sup.len++;
						asgnRef((void**) (&(*libpaths)._kind_7.elems->data[T115_]), T114_);
						i += ((NI) 1);
					} LA113: ;
				}
			}
			{
				NimStringDesc** dir_2;
				NI i_2;
				NI L_2;
				NI T117_;
				dir_2 = (NimStringDesc**)0;
				i_2 = ((NI) 0);
				T117_ = ((*(*colonenv_).conf2).lazyPaths ? (*(*colonenv_).conf2).lazyPaths->Sup.len : 0);
				L_2 = T117_;
				{
					while (1) {
						tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T120_;
						NI T121_;
						if (!(i_2 < L_2)) goto LA119;
						dir_2 = (&(*(*colonenv_).conf2).lazyPaths->data[i_2]);
						T120_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
						T120_ = percent___19ag6cl4fMjxytc9arHmLIbw_3((*dir_2));
						asgnRef((void**) (&(*lazyPaths)._kind_7.elems), (tySequence__oLpBKXzW3hF9aCVMo5EymfQ*) incrSeqV3((TGenericSeq*)((*lazyPaths)._kind_7.elems), (&NTI__oLpBKXzW3hF9aCVMo5EymfQ_)));
						T121_ = (*lazyPaths)._kind_7.elems->Sup.len++;
						asgnRef((void**) (&(*lazyPaths)._kind_7.elems->data[T121_]), T120_);
						i_2 += ((NI) 1);
					} LA119: ;
				}
			}
			hints = newJObject__nXwnFPu9beTnGPwglrr7ztA_2();
			{
				tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w a;
				NI res_2;
				a = (tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w)0;
				res_2 = ((NI) 52);
				{
					while (1) {
						tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T125_;
						if (!(res_2 <= ((NI) 83))) goto LA124;
						a = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) (res_2));
						T125_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
						T125_ = percent___cUNUWspDCIapW3x6fFYyZQ_2((((*(*colonenv_).conf2).notes[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (a))- 12))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (a))- 12))&7U)))!=0));
						X5BX5Deq___WmQhibcOp3ZlzI9bgifjalAjson(hints, reprEnum((NI)a, (&NTI__29cbg2fC1z5iM1PAI28kR5w_)), T125_);
						res_2 += ((NI) 1);
					} LA124: ;
				}
			}
			warnings = newJObject__nXwnFPu9beTnGPwglrr7ztA_2();
			{
				tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w a_2;
				NI res_3;
				a_2 = (tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w)0;
				res_3 = ((NI) 12);
				{
					while (1) {
						tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T129_;
						if (!(res_3 <= ((NI) 51))) goto LA128;
						a_2 = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) (res_3));
						T129_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
						T129_ = percent___cUNUWspDCIapW3x6fFYyZQ_2((((*(*colonenv_).conf2).notes[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (a_2))- 12))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (a_2))- 12))&7U)))!=0));
						X5BX5Deq___WmQhibcOp3ZlzI9bgifjalAjson(warnings, reprEnum((NI)a_2, (&NTI__29cbg2fC1z5iM1PAI28kR5w_)), T129_);
						res_3 += ((NI) 1);
					} LA128: ;
				}
			}
			nimZeroMem((void*)T130_, sizeof(tyArray__4UNJAnCX9cgpcB9c9aDb4OAnA));
			T130_[0].Field0 = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_65));
			T130_[0].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_66));
			T130_[1].Field0 = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_67));
			T131_ = (NimStringDesc*)0;
			T131_ = nosgetAppFilename();
			T130_[1].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(T131_);
			T130_[2].Field0 = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_68));
			T132_ = (NimStringDesc*)0;
			T132_ = getPrefixDir__oltK69akg0xLqkR2ITKbomg((*colonenv_).conf2);
			T130_[2].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(T132_);
			T130_[3].Field0 = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_69));
			T130_[3].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3((*(*colonenv_).conf2).libpath);
			T130_[4].Field0 = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_70));
			T130_[4].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3((*(*colonenv_).conf2).projectFull);
			T130_[5].Field0 = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_71));
			T130_[5].Field1 = definedSymbols;
			T130_[6].Field0 = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_72));
			T130_[6].Field1 = libpaths;
			T130_[7].Field0 = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_73));
			T130_[7].Field1 = lazyPaths;
			T130_[8].Field0 = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_74));
			T130_[8].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3((*(*colonenv_).conf2).outDir);
			T130_[9].Field0 = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_75));
			T130_[9].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3((*(*colonenv_).conf2).outFile);
			T130_[10].Field0 = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_76));
			T133_ = (NimStringDesc*)0;
			T133_ = getNimcacheDir__oltK69akg0xLqkR2ITKbomg_2((*colonenv_).conf2);
			T130_[10].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(T133_);
			T130_[11].Field0 = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_77));
			T130_[11].Field1 = hints;
			T130_[12].Field0 = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_78));
			T130_[12].Field1 = warnings;
			dumpdata = percent___HoVDUa0lAOcINNYBrrSTiA(T130_, 13);
			T134_ = (NimStringDesc*)0;
			T134_ = dollar___79aIqF5QC8ZRJgu2hlv9bdjw(dumpdata);
			msgWriteln__PO49anyWCbe63GYNOs9cVuvg((*colonenv_).conf2, T134_, 3);
		}
		goto LA93_;
		LA96_: ;
		{
			msgWriteln__PO49anyWCbe63GYNOs9cVuvg((*colonenv_).conf2, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_79), 3);
			{
				NimStringDesc* s_2;
				s_2 = (NimStringDesc*)0;
				{
					NimStringDesc* key_2;
					NimStringDesc* val_2;
					key_2 = (NimStringDesc*)0;
					val_2 = (NimStringDesc*)0;
					{
						NI h_2;
						NI colontmp__2;
						NI T139_;
						NI res_4;
						h_2 = (NI)0;
						colontmp__2 = (NI)0;
						T139_ = (((*(*(*colonenv_).conf2).symbols).data ? (*(*(*colonenv_).conf2).symbols).data->Sup.len : 0)-1);
						colontmp__2 = T139_;
						res_4 = ((NI) 0);
						{
							while (1) {
								if (!(res_4 <= colontmp__2)) goto LA141;
								h_2 = res_4;
								{
									if (!(*(*(*colonenv_).conf2).symbols).data->data[h_2].Field2) goto LA144_;
									key_2 = (*(*(*colonenv_).conf2).symbols).data->data[h_2].Field0;
									val_2 = (*(*(*colonenv_).conf2).symbols).data->data[h_2].Field1;
									s_2 = key_2;
									msgWriteln__PO49anyWCbe63GYNOs9cVuvg((*colonenv_).conf2, s_2, 3);
								}
								LA144_: ;
								res_4 += ((NI) 1);
							} LA141: ;
						}
					}
				}
			}
			msgWriteln__PO49anyWCbe63GYNOs9cVuvg((*colonenv_).conf2, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_80), 3);
			{
				NimStringDesc** it;
				NI i_3;
				NI L_3;
				NI T147_;
				it = (NimStringDesc**)0;
				i_3 = ((NI) 0);
				T147_ = ((*(*colonenv_).conf2).searchPaths ? (*(*colonenv_).conf2).searchPaths->Sup.len : 0);
				L_3 = T147_;
				{
					while (1) {
						if (!(i_3 < L_3)) goto LA149;
						it = (&(*(*colonenv_).conf2).searchPaths->data[i_3]);
						msgWriteln__PO49anyWCbe63GYNOs9cVuvg((*colonenv_).conf2, (*it), 0);
						i_3 += ((NI) 1);
					} LA149: ;
				}
			}
		}
		LA93_: ;
	}
	goto LA74_;
	LA66_: ;
	{
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 11);
		commandCheck__ikP0vuP6oxqlYdG7q9cY7sA_5((*colonenv_).graph3);
	}
	goto LA74_;
	LA67_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T152_;
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 12);
		wantMainModule__pfNwDAcuVGDsWqOQBMvUpw((*colonenv_).conf2);
		T152_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T152_ = parseFile__HSBHiITVPKlv327uAC12yw((*(*colonenv_).conf2).projectMainIdx, cache, (*colonenv_).conf2);
		(void)(T152_);
	}
	goto LA74_;
	LA68_: ;
	{
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 13);
		wantMainModule__pfNwDAcuVGDsWqOQBMvUpw((*colonenv_).conf2);
		commandScan__Ka9c1FxVXU1B1XFhzMdeNfg(cache, (*colonenv_).conf2);
		msgWriteln__PO49anyWCbe63GYNOs9cVuvg((*colonenv_).conf2, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_85), 0);
	}
	goto LA74_;
	LA69_: ;
	{
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 18);
		commandInteractive__ikP0vuP6oxqlYdG7q9cY7sA_6((*colonenv_).graph3);
	}
	goto LA74_;
	LA70_: ;
	{
		{
			NIM_BOOL T158_;
			NimStringDesc* T161_;
			T158_ = (NIM_BOOL)0;
			T158_ = nosfileExists((*(*colonenv_).conf2).projectFull);
			if (!!(T158_)) goto LA159_;
			T161_ = (NimStringDesc*)0;
			T161_ = rawNewString(((*(*colonenv_).conf2).projectFull ? (*(*colonenv_).conf2).projectFull->Sup.len : 0) + 31);
appendString(T161_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_88));
appendString(T161_, (*(*colonenv_).conf2).projectFull);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenv_).conf2, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T161_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__LO85BC9bl7tvXIPU7J9cRbtA_89, NIM_FALSE);
		}
		goto LA156_;
		LA159_: ;
		{
			NIM_BOOL T163_;
			NimStringDesc* T166_;
			T163_ = (NIM_BOOL)0;
			T163_ = nsuEndsWith((*(*colonenv_).conf2).projectFull, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_90));
			if (!!(T163_)) goto LA164_;
			T166_ = (NimStringDesc*)0;
			T166_ = rawNewString(((*(*colonenv_).conf2).projectFull ? (*(*colonenv_).conf2).projectFull->Sup.len : 0) + 22);
appendString(T166_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_91));
appendString(T166_, (*(*colonenv_).conf2).projectFull);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenv_).conf2, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T166_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__LO85BC9bl7tvXIPU7J9cRbtA_92, NIM_FALSE);
		}
		goto LA156_;
		LA164_: ;
		LA156_: ;
	}
	goto LA74_;
	LA71_: ;
	{
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 10);
	}
	goto LA74_;
	LA72_: ;
	{
		(*(*colonenv_).conf2).cmd = ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 20);
		setOutFile__CQGypz7djD4eDZIXokhWpg_4((*(*colonenv_).graph3).config);
		commandJsonScript__ikP0vuP6oxqlYdG7q9cY7sA_8((*colonenv_).graph3);
	}
	goto LA74_;
	LA73_: ;
	{
		{
			if (!(*colonenv_).commandAlreadyProcessed1) goto LA172_;
		}
		goto LA170_;
		LA172_: ;
		{
			NimStringDesc* T175_;
			T175_ = (NimStringDesc*)0;
			T175_ = rawNewString(((*(*colonenv_).conf2).command ? (*(*colonenv_).conf2).command->Sup.len : 0) + 17);
appendString(T175_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_93));
appendString(T175_, (*(*colonenv_).conf2).command);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenv_).conf2, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T175_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__LO85BC9bl7tvXIPU7J9cRbtA_94, NIM_FALSE);
		}
		LA170_: ;
	}
	LA74_: ;
	{
		NIM_BOOL T178_;
		NimStringDesc* mem;
		NimStringDesc* T182_;
		NI T183_;
		NimStringDesc* T184_;
		NimStringDesc* loc;
		NimStringDesc* build;
		NimStringDesc* sec;
		NF T195_;
		NimStringDesc* project;
		NimStringDesc* output;
		NimStringDesc* argX60gensym52_;
		NimStringDesc* T223_;
		tyArray__ucDUDWdKfioXQrN9bCbG29bg T224_;
		T178_ = (NIM_BOOL)0;
		T178_ = ((*(*colonenv_).conf2).errorCounter == ((NI) 0));
		if (!(T178_)) goto LA179_;
		T178_ = !(((525376 &((NU32)1<<((NU)((*(*colonenv_).conf2).cmd)&31U)))!=0));
		LA179_: ;
		if (!T178_) goto LA180_;
		T182_ = (NimStringDesc*)0;
		T183_ = (NI)0;
		T183_ = getMaxMem__hrQB9bN29c1nR1E9cHqYcNcDA_2();
		T184_ = (NimStringDesc*)0;
		T184_ = formatSize__sJSibvv0Wr8GrWWSB9cNm9aw(((NI64) (T183_)), 46, ((tyEnum_BinaryPrefixMode__nDtrM19b3byM8T9ab2m7BwvA) 0), NIM_FALSE);
		T182_ = rawNewString((T184_ ? T184_->Sup.len : 0) + 8);
appendString(T182_, T184_);
appendString(T182_, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_95));
		mem = T182_;
		loc = nimIntToStr((*(*colonenv_).conf2).linesCompiled);
		{
			NIM_BOOL T187_;
			T187_ = (NIM_BOOL)0;
			T187_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA((*colonenv_).conf2, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_96));
			if (!T187_) goto LA188_;
			build = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_97));
		}
		goto LA185_;
		LA188_: ;
		{
			NIM_BOOL T191_;
			T191_ = (NIM_BOOL)0;
			T191_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA((*colonenv_).conf2, ((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_98));
			if (!T191_) goto LA192_;
			build = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_99));
		}
		goto LA185_;
		LA192_: ;
		{
			build = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_100));
		}
		LA185_: ;
		T195_ = (NF)0;
		T195_ = epochTime__9aodCrWXscOGeNVh2cpuZkw_2();
		sec = nsuformatFloat(((NF)(T195_) - (NF)((*(*colonenv_).conf2).lastCmdTime)), ((tyEnum_FloatFormatMode__pNvEoaqwoxKyoASD11vSgQ) 1), ((NI) 3), 46);
		{
			if (!(((*(*colonenv_).conf2).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 36))&63U)))!=0)) goto LA198_;
			project = dollar___l9cjIIY6CNqmzrJ1PC9apeYg((*(*colonenv_).conf2).projectFull);
		}
		goto LA196_;
		LA198_: ;
		{
			project = (*(*colonenv_).conf2).projectName;
		}
		LA196_: ;
		output = (NimStringDesc*)0;
		{
			NIM_BOOL T203_;
			T203_ = (NIM_BOOL)0;
			T203_ = (((*(*colonenv_).conf2).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 4))&63U)))!=0);
			if (!(T203_)) goto LA204_;
			T203_ = !(((*(*colonenv_).conf2).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 20)));
			LA204_: ;
			if (!T203_) goto LA205_;
			output = dollar___l9cjIIY6CNqmzrJ1PC9apeYg((*(*colonenv_).conf2).jsonBuildFile);
		}
		goto LA201_;
		LA205_: ;
		{
			NIM_BOOL T208_;
			T208_ = (NIM_BOOL)0;
			T208_ = isEmpty__bFmAIl9aL9a1UuSf9ckLiDlVwpathutils((*(*colonenv_).conf2).outFile);
			if (!(T208_)) goto LA209_;
			T208_ = !(((3145984 &((NU32)1<<((NU)((*(*colonenv_).conf2).cmd)&31U)))!=0));
			LA209_: ;
			if (!T208_) goto LA210_;
			output = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_101));
		}
		goto LA201_;
		LA210_: ;
		{
			NimStringDesc* T213_;
			T213_ = (NimStringDesc*)0;
			T213_ = absOutFile__ea9bsNo9cwchKzwCi7UjcP7g((*colonenv_).conf2);
			output = dollar___l9cjIIY6CNqmzrJ1PC9apeYg(T213_);
		}
		LA201_: ;
		{
			if (!!((((*(*colonenv_).conf2).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 36))&63U)))!=0))) goto LA216_;
			output = nosextractFilename(output);
		}
		LA216_: ;
		{
			tyArray__nHXaesL0DJZHyVS07ARPRA T222_;
			if (!(((*(*colonenv_).conf2).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 50))&63U)))!=0)) goto LA220_;
			nimZeroMem((void*)T222_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
			T222_[0] = dump__Mb6F9aWuAmny8imBUjTGzOw((*colonenv_).conf2, (*(*colonenv_).conf2).vmProfileData);
			echoBinSafe(T222_, 1);
		}
		LA220_: ;
		T223_ = (NimStringDesc*)0;
		T223_ = msgKindToString__pY9bbQrdTPzM2HGfayOe6eQ(((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 53));
		nimZeroMem((void*)T224_, sizeof(tyArray__ucDUDWdKfioXQrN9bCbG29bg));
		T224_[0] = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_102));
		T224_[1] = copyString(loc);
		T224_[2] = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_103));
		T224_[3] = copyString(sec);
		T224_[4] = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_104));
		T224_[5] = copyString(mem);
		T224_[6] = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_105));
		T224_[7] = copyString(build);
		T224_[8] = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_106));
		T224_[9] = copyString(project);
		T224_[10] = copyString(((NimStringDesc*) &TM__LO85BC9bl7tvXIPU7J9cRbtA_107));
		T224_[11] = copyString(output);
		argX60gensym52_ = nsuFormatOpenArray(T223_, T224_, 12);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenv_).conf2, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 53), argX60gensym52_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__LO85BC9bl7tvXIPU7J9cRbtA_108, NIM_TRUE);
	}
	LA180_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_mainDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__LO85BC9bl7tvXIPU7J9cRbtA_2_4[4];
static TNimNode TM__LO85BC9bl7tvXIPU7J9cRbtA_0[5];

/* section: NIM_merge_TYPE_INIT3 */
NTI__p9aeeIinIungzas8OX4XRoQ_.size = sizeof(tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ);
NTI__p9aeeIinIungzas8OX4XRoQ_.align = NIM_ALIGNOF(tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ);
NTI__p9aeeIinIungzas8OX4XRoQ_.kind = 17;
NTI__p9aeeIinIungzas8OX4XRoQ_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__LO85BC9bl7tvXIPU7J9cRbtA_2_4[0] = &TM__LO85BC9bl7tvXIPU7J9cRbtA_0[1];
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[1].kind = 1;
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[1].offset = offsetof(tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ, colonstate_);
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[1].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[1].name = ":state";
TM__LO85BC9bl7tvXIPU7J9cRbtA_2_4[1] = &TM__LO85BC9bl7tvXIPU7J9cRbtA_0[2];
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[2].kind = 1;
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[2].offset = offsetof(tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ, commandAlreadyProcessed1);
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[2].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[2].name = "commandAlreadyProcessed1";
TM__LO85BC9bl7tvXIPU7J9cRbtA_2_4[2] = &TM__LO85BC9bl7tvXIPU7J9cRbtA_0[3];
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[3].kind = 1;
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[3].offset = offsetof(tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ, conf2);
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[3].typ = (&NTI__a8lycfSA25OQltN3OMeBsA_);
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[3].name = "conf2";
TM__LO85BC9bl7tvXIPU7J9cRbtA_2_4[3] = &TM__LO85BC9bl7tvXIPU7J9cRbtA_0[4];
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[4].kind = 1;
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[4].offset = offsetof(tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ, graph3);
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[4].typ = (&NTI__KfdHSsl8vyUCSI9b3inBcww_);
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[4].name = "graph3";
TM__LO85BC9bl7tvXIPU7J9cRbtA_0[0].len = 4; TM__LO85BC9bl7tvXIPU7J9cRbtA_0[0].kind = 2; TM__LO85BC9bl7tvXIPU7J9cRbtA_0[0].sons = &TM__LO85BC9bl7tvXIPU7J9cRbtA_2_4[0];
NTI__p9aeeIinIungzas8OX4XRoQ_.node = &TM__LO85BC9bl7tvXIPU7J9cRbtA_0[0];
NTI__Df2d8g8ATJgl6P2dnvrxRQ_.size = sizeof(tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ*);
NTI__Df2d8g8ATJgl6P2dnvrxRQ_.align = NIM_ALIGNOF(tyObject_Env_maindotnim_mainCommand___p9aeeIinIungzas8OX4XRoQ*);
NTI__Df2d8g8ATJgl6P2dnvrxRQ_.kind = 22;
NTI__Df2d8g8ATJgl6P2dnvrxRQ_.base = (&NTI__p9aeeIinIungzas8OX4XRoQ_);
NTI__Df2d8g8ATJgl6P2dnvrxRQ_.marker = Marker_tyRef__Df2d8g8ATJgl6P2dnvrxRQ;
}

